aboutsummaryrefslogtreecommitdiffstats
path: root/activesupport/lib/active_support/core_ext/array
diff options
context:
space:
mode:
Diffstat (limited to 'activesupport/lib/active_support/core_ext/array')
-rw-r--r--activesupport/lib/active_support/core_ext/array/wrapper.rb9
1 files changed, 7 insertions, 2 deletions
diff --git a/activesupport/lib/active_support/core_ext/array/wrapper.rb b/activesupport/lib/active_support/core_ext/array/wrapper.rb
index 12fd745b1a..80b8f05531 100644
--- a/activesupport/lib/active_support/core_ext/array/wrapper.rb
+++ b/activesupport/lib/active_support/core_ext/array/wrapper.rb
@@ -2,7 +2,8 @@ module ActiveSupport #:nodoc:
module CoreExtensions #:nodoc:
module Array #:nodoc:
module Wrapper
# Wraps the object in an Array unless it's an Array.
def wrap(object)
case object
when nil
@@ -10,7 +11,11 @@ module ActiveSupport #:nodoc:
when self
object
else
- [object]
+ if object.respond_to?(:to_ary)
+ object.to_ary
+ else
+ [object]
+ end
end
end
end
@@ -2,7 +2,8 @@ module ActiveSupport #:nodoc:
module Array #:nodoc:
module Wrapper
- # Wraps the object in an Array unless it's an Array.
+ # Wraps the object in an Array unless it's an Array. Converts the
+ # object to an Array using #to_ary if it implements that.
def wrap(object)
case object